import React, { useState } from 'react';

const SortableTable = ({ data }) => {
    const [sortConfig, setSortConfig] = useState({ key: null, direction: 'asc' });

    const sortedData = React.useMemo(() => {
        if (!sortConfig.key) return data;

        return [...data].sort((a, b) => {
            if (a[sortConfig.key] < b[sortConfig.key]) return sortConfig.direction === 'asc' ? -1 : 1;
            if (a[sortConfig.key] > b[sortConfig.key]) return sortConfig.direction === 'asc' ? 1 : -1;
            return 0;
        });
    }, [data, sortConfig]);

    const handleSort = (key) => {
        if (sortConfig.key === key) {
            setSortConfig({
                key,
                direction: sortConfig.direction === 'asc' ? 'desc' : 'asc',
            });
        } else {
            setSortConfig({ key, direction: 'asc' });
        }
    };

    return (
        <table className="w-full text-sm text-left text-gray-500">
            <thead className="text-xs text-gray-700 uppercase bg-gray-100">
                <tr>
                    <th
                        className="cursor-pointer px-4 py-2"
                        onClick={() => handleSort('name')}
                    >
                        Nome {sortConfig.key === 'name' ? (sortConfig.direction === 'asc' ? '🔼' : '🔽') : ''}
                    </th>
                    <th
                        className="cursor-pointer px-4 py-2"
                        onClick={() => handleSort('age')}
                    >
                        Idade {sortConfig.key === 'age' ? (sortConfig.direction === 'asc' ? '🔼' : '🔽') : ''}
                    </th>
                    <th
                        className="cursor-pointer px-4 py-2"
                        onClick={() => handleSort('country')}
                    >
                        País {sortConfig.key === 'country' ? (sortConfig.direction === 'asc' ? '🔼' : '🔽') : ''}
                    </th>
                </tr>
            </thead>
            <tbody>
                {sortedData.map((item, index) => (
                    <tr key={index} className="border-b">
                        <td className="px-4 py-2">{item.name}</td>
                        <td className="px-4 py-2">{item.age}</td>
                        <td className="px-4 py-2">{item.country}</td>
                    </tr>
                ))}
            </tbody>
        </table>
    );
};

export default SortableTable;
